#[macro_use]
mod cast;

mod bool;
mod f16;
mod f32;
mod f64;
mod func;
mod i128;
mod i16;
mod i32;
mod i64;
mod i8;
mod isize;
mod nalgebra;
mod tuples;
mod u128;
mod u16;
mod u32;
mod u64;
mod u8;
mod usize;
mod vector;

pub mod result;

pub use {cast::Cast, func::*};
